.. _pdf_reference:

Reference
*********

   :Release: |release|
   :Date: |today|


.. toctree::
   :maxdepth: 2

   ../overview	
   introduction
   classes
   algorithms
   functions
   generators
   linalg
   convert
   readwrite
   drawing
   exceptions
   utils
   legal
   citing	
   credits
   glossary
